@@ -6,7 +6,7 @@
 /// This function is unsafe as it causes a general protection fault (GP) if the current privilege
 /// level is not 0.
 pub unsafe fn flush(addr: usize) {
-    llvm_asm!("invlpg ($0)" :: "r" (addr) : "memory");
+    asm!("invlpg ({})", in(reg) addr, options(att_syntax, nostack, preserves_flags));
 }
 
 /// Invalidate the TLB completely by reloading the CR3 register.
